@@ -58,15 +58,15 @@ class ComputerExcludeOneOf(BaseObject):
 
         if self.isEnabledForInfo:
             self.logger.debug('\n'.join([
-                "Computation Complete: Exclude One Of",
-                f"\tTotal Mapping: {len(s_mapping)}",
-                f"\tTotal Input Tokens: {len(s_input_tokens)}",
-                f"\tTotal Candidates: {len(mapping)}",
-                f"\tTotal Time: {str(sw)}"]))
+                'Computation Complete: Exclude One Of',
+                f'\tTotal Mapping: {len(s_mapping)}',
+                f'\tTotal Input Tokens: {len(s_input_tokens)}',
+                f'\tTotal Candidates: {len(mapping)}',
+                f'\tTotal Time: {str(sw)}']))
 
         if self.isEnabledForDebug and len(d_results):
             self.logger.debug('\n'.join([
-                "EXCLUDE_ONE_OF Results:",
-                f"{pformat(d_results)}"]))
+                'EXCLUDE_ONE_OF Results:',
+                f'{pformat(d_results)}']))
 
         return d_results
