@@ -100,7 +100,7 @@ class ComputerIncludeAllOf(BaseObject):
             for mapping in candidate['mappings']:
                 weight = 1 + len(candidate['terms'])
                 coverage = 100.0  # coverage is always 100% for include-all-of by design
-                d[mapping] = {"weight": weight, "coverage": coverage}
+                d[mapping] = {'weight': weight, 'coverage': coverage}
 
         return d
 
@@ -116,14 +116,14 @@ class ComputerIncludeAllOf(BaseObject):
 
         if self.isEnabledForInfo:
             self.logger.info('\n'.join([
-                "Computation Complete: Include All Of",
-                f"\tTotal Input Tokens: {len(d_input_tokens)}",
-                f"\tTotal Results: {len(d_results)}",
-                f"\tTotal Time: {str(sw)}"]))
+                'Computation Complete: Include All Of',
+                f'\tTotal Input Tokens: {len(d_input_tokens)}',
+                f'\tTotal Results: {len(d_results)}',
+                f'\tTotal Time: {str(sw)}']))
 
         if self.isEnabledForDebug and len(d_results):
             self.logger.debug('\n'.join([
-                "INCLUDE_ALL_OF Results:",
-                f"{pformat(d_results)}"]))
+                'INCLUDE_ALL_OF Results:',
+                f'{pformat(d_results)}']))
 
         return d_results
