@@ -63,12 +63,12 @@ class ComputerStartsWith(BaseObject):
             if input_text.startswith(phrase.lower()):
 
                 for mapping in self._d_startswith[phrase]:
-                    d_results[mapping] = {"weight": 100.0, "coverage": 100.0}
+                    d_results[mapping] = {'weight': 100.0, 'coverage': 100.0}
 
         if self.isEnabledForDebug and len(d_results):
             self.logger.debug('\n'.join([
-                "StartsWith Results:",
-                f"\tTotal Time: {str(sw)}",
-                f"\t{pformat(d_results)}"]))
+                'StartsWith Results:',
+                f'\tTotal Time: {str(sw)}',
+                f'\t{pformat(d_results)}']))
 
         return d_results
