@@ -62,13 +62,13 @@ class IndexIncludeAllOf(BaseObject):
 
                     if not update_existing_flag:
                         d[cluster[0]].append({  # NLP-889-12304; an example of this structure
-                            "mappings": [k],
-                            "terms": terms_n})
+                            'mappings': [k],
+                            'terms': terms_n})
 
         if self.isEnabledForDebug:
             self.logger.debug('\n'.join([
-                "Generated Index: Include All Of",
-                f"\tTotal Rows: {len(d)}",
-                f"\tTotal Time: {str(sw)}"]))
+                'Generated Index: Include All Of',
+                f'\tTotal Rows: {len(d)}',
+                f'\tTotal Time: {str(sw)}']))
 
         return dict(d)
