@@ -46,8 +46,8 @@ class IndexIncludeOneOf(BaseObject):
 
         if self.isEnabledForDebug:
             self.logger.debug('\n'.join([
-                "Generated Index: Include One Of",
-                f"\tTotal Rows: {len(d)}",
-                f"\tTotal Time: {str(sw)}"]))
+                'Generated Index: Include One Of',
+                f'\tTotal Rows: {len(d)}',
+                f'\tTotal Time: {str(sw)}']))
 
         return dict(d)
