@@ -49,8 +49,8 @@ class IndexScoring(BaseObject):
 
         if self.isEnabledForDebug:
             self.logger.debug('\n'.join([
-                "Generated Index: Scoring",
-                f"\tTotal Rows: {len(d)}",
-                f"\tTotal Time: {str(sw)}"]))
+                'Generated Index: Scoring',
+                f'\tTotal Rows: {len(d)}',
+                f'\tTotal Time: {str(sw)}']))
 
         return d
