@@ -77,15 +77,15 @@ class InputTokensTransform(BaseObject):
                     'spaCy ENT type not mappped',
                     f"\tENT: {token['ent']}"]))
 
-        return ""
+        return ''
 
     def _process(self) -> list:
         results = []
 
         for d_token in self._input_tokens:
             results.append({
-                "name": self._name(d_token),
-                "type": self._type(d_token),
+                'name': self._name(d_token),
+                'type': self._type(d_token),
             })
 
         # GRAFFL-170-1032853911; ultra simplified output
@@ -97,8 +97,8 @@ class InputTokensTransform(BaseObject):
         results = self._process()
 
         self.logger.debug('\n'.join([
-            "Input Token Transformation Completed",
-            f"\tTotal Tokens: {len(results)}",
-            f"\tTotal Time: {str(sw)}"]))
+            'Input Token Transformation Completed',
+            f'\tTotal Tokens: {len(results)}',
+            f'\tTotal Time: {str(sw)}']))
 
         return results
