@@ -62,7 +62,7 @@ class MappingFindCandidates(BaseObject):
                     inner_map = d_map[k]
 
                     # Add Recursion Level
-                    inner_map["recursion"] = recursion_level()
+                    inner_map['recursion'] = recursion_level()
 
                     d_result[k] = inner_map
 
@@ -90,9 +90,9 @@ class MappingFindCandidates(BaseObject):
         d_consolidated = self._consolidate(diff)
 
         self.logger.debug('\n'.join([
-            "Located Candidate Mappings",
-            f"\tInclude: {include}",
-            f"\tExclude: {exclude}",
-            f"\tDifference: {diff}"]))
+            'Located Candidate Mappings',
+            f'\tInclude: {include}',
+            f'\tExclude: {exclude}',
+            f'\tDifference: {diff}']))
 
         return d_consolidated
