@@ -132,6 +132,6 @@ class MappingRemoveDuplicates(BaseObject):
         # Minimize Scoring on Discards
         for k in d_results:
             if k in discards:
-                d_results[k]["score"] = 0
+                d_results[k]['score'] = 0
 
         return d_results
