@@ -83,7 +83,7 @@ class MappingScoreCandidates(BaseObject):
     def process(self,
                 d_results: Dict) -> Dict:
         for k in d_results:
-            d_results[k]["score"] = self._score(k,
+            d_results[k]['score'] = self._score(k,
                                                 d_results[k])
 
         return d_results
