@@ -57,7 +57,7 @@ class MappingSelectCandidates(BaseObject):
 
         final_results = []
         for result in max_results:
-            final_results.append({"classification": result[0],
-                                  "confidence": result[1]['score']})
+            final_results.append({'classification': result[0],
+                                  'confidence': result[1]['score']})
 
         return final_results
