@@ -5,6 +5,8 @@
 """ Build an in-memory Index over a Dictionary of Classifications """
 
 
+from typing import Dict
+
 from baseblock import FileIO
 from baseblock import BaseObject
 
@@ -22,7 +24,7 @@ class ReadMapping(BaseObject):
     """ Build an in-memory Index over a Dictionary of Classifications """
 
     def __init__(self,
-                 schema_file: str):
+                 d_schema: Dict):
         """ Initialize Manifest Indicer
 
         Created:
@@ -40,12 +42,16 @@ class ReadMapping(BaseObject):
             *   remove 'schema-name' and 'absolute-path' as parameters, and instead
                 pass the full absolute path of a schema file, in pursuit of
                 https://bast-ai.atlassian.net/browse/COR-12
+        Updated:
+            26-Sept-2022
+            craigtrim@gmail.com
+            *   pass in d-schema as dict rather than a filepath
+                https://github.com/craigtrim/schema-classification/issues/1
 
         Args:
-            schema_file (str): the absolute path to a local schema file containing classification rules
+            d_schema (Dict): the schema JSON
         """
         BaseObject.__init__(self, __name__)
-        d_schema = FileIO.read_yaml(schema_file)
         self._d_index = self._create_index(d_schema)
 
     def _create_index(self,
