@@ -47,8 +47,8 @@ class SelectMapping(BaseObject):
         BaseObject.__init__(self, __name__)
         if self.isEnabledForDebug:
             self.logger.debug('\n'.join([
-                "Initialized Service",
-                f"\tTotal Results: {len(results)}"]))
+                'Initialized Service',
+                f'\tTotal Results: {len(results)}']))
 
         self._results = results
         self._d_index = d_index
